@@ -92,7 +92,7 @@
       l7ruleTypes: ['HOST_NAME', 'PATH', 'FILE_TYPE', 'HEADER', 'COOKIE'],
       l7ruleCompareTypes: ['REGEX', 'EQUAL_TO', 'STARTS_WITH', 'ENDS_WITH', 'CONTAINS'],
       l7ruleFileTypeCompareTypes: ['REGEX', 'EQUAL_TO'],
-      poolProtocols: ['HTTP', 'HTTPS', 'PROXY', 'TCP', 'UDP'],
+      poolProtocols: ['HTTP', 'HTTPS', 'PROXY', 'PROXYV2', 'TCP', 'UDP'],
       methods: ['LEAST_CONNECTIONS', 'ROUND_ROBIN', 'SOURCE_IP'],
       types: ['SOURCE_IP', 'HTTP_COOKIE', 'APP_COOKIE'],
       monitorTypes: ['HTTP', 'HTTPS', 'PING', 'TCP', 'TLS-HELLO', 'UDP-CONNECT'],
@@ -481,6 +481,10 @@
         finalSpec.loadbalancer.flavor_id = finalSpec.loadbalancer.flavor_id.id;
       }
 
+      if (angular.isObject(finalSpec.loadbalancer.availability_zone)) {
+        finalSpec.loadbalancer.availability_zone = finalSpec.loadbalancer.availability_zone.name;
+      }
+
       // Load balancer requires vip_subnet_id
       if (!finalSpec.loadbalancer.vip_subnet_id) {
         delete finalSpec.loadbalancer;
